@@ -142,7 +142,7 @@ pub enum Instruction<'source> {
     LoadBlocks,
 
     /// Includes another template.
-    Include,
+    Include(bool),
 
     /// Sets the auto escape flag to the current value.
     PushAutoEscape,
@@ -238,7 +238,7 @@ impl<'source> fmt::Debug for Instruction<'source> {
             Instruction::JumpIfTrueOrPop(t) => write!(f, "JUMP_IF_TRUE_OR_POP (to {:>05x})", t),
             Instruction::CallBlock(n) => write!(f, "CALL_BLOCK (name {:?})", n),
             Instruction::LoadBlocks => write!(f, "LOAD_BLOCKS"),
-            Instruction::Include => write!(f, "INCLUDE"),
+            Instruction::Include(b) => write!(f, "INCLUDE (ignore missing {:?})", b),
             Instruction::PushAutoEscape => write!(f, "PUSH_AUTO_ESCAPE"),
             Instruction::PopAutoEscape => write!(f, "POP_AUTO_ESCAPE"),
             Instruction::BeginCapture => write!(f, "BEGIN_CAPTURE"),
